#!/usr/bin/perl


=pod

=head1 NAME

get-idents-from-html.pl - a script to gather a names and ids of elements
used inside a set of html files.

=head1 SYNOPSIS

B<get-idents-from-html.pl> 
    S<[ B<--for-ids=names-of-elements-to-take-ID-from> ]>
    S<[ B<--for-names=names-of-elements-to-take-NAME-from> ]>
    S<[ B<-i> ] [ B<--runat> I<client>|I<any>|I<server> ] > 
    S<[ B<-l=file-name-with-list-of-src-files> ] [ B<--do-not-merge> ] >
    S<I<destfile> I<srchtmlfiles>..>

=head1 DESCRIPTION

If your script referers to form fields by their names (using them as properties
in case of JavaScript or by exporting them as variables into special namespace
in case of e.g. Perl), there needs to be a way to form a list of names of form 
fields to use it as a set of exceptions. This utility is just for this purpose - 
for extracting names and ids of html elements - from their B<NAME> and B<ID>
attributes; it puts resultant list of processing I<srchtmlfiles> to the 
I<destfile> in sorted form, one symbol on each line.

The I<srchtmlfiles> processed needn't be valid HTML - they can even be XML 
files, no balancing of tags and allowance of containment is checked. The
names of elements and attributes can be in any case, even mixed case is OK.

By default, values of all attributes with name B<NAME> (except B<A>) are 
extracted; also values of all attributes with name B<ID> are extracted too. 
It's  possible to specify the exact list of names (as a comma-separated 
list specified as a single string) of elements from which
to extract values of B<NAME> attribute using commandline option B<--for-names>,
and names of elements from which
to extract values of B<ID> attribute using commandline option B<--for-ids>.
Values of corresponding attributes not looking like identifier are ignored.

It's possible ignore the case of extracted symbol names, by adding option
B<-i> - in this case encountering e.g. form fields with ids I<E1> and I<e1> 
will be  result in a single line I<e1> to be output to the resultant file.

By default, elements with attribute B<runat> with value I<server> (used by
ASP and ASP.NET for marking server-side objects) are ignored. It's also 
possible to request to also analyze them, or to analyze only elements with
I<runat=server> by the use of B<--runat> commandline option.

=head1 OPTIONS

=over 4

=item B<--for-ids=names-of-elements-to-take-ID-from>

Specify the list of elements from which to take the value of attribute B<ID>.
The I<names-of-elements-to-take-ID-from> is a string that is 
comma-separated list of element names in to be inspected, e.g 
C<object,select,input>.
By default the value of attribute B<ID> is taken from all elements that have
attribute with this name specified.


=item B<--for-names=names-of-elements-to-take-NAME-from>

Specify the list of elements from which to take the value of attribute B<NAME>.
The I<names-of-elements-to-take-NAME-from> is a string that is 
comma-separated list of  lement names in to be inspected, e.g 
C<object,select,input>.
By default the value of attribute B<NAME> is taken from all elements that have
attribute with this name specified, except element with name B<A>.

=item B<-i>

Passing this option requests not to distinguish the case of aggregated 
symbols - all extracted symbols are mapped to lowercase and then duplicates 
are ignored. By default case is preserved.

=item B<--runat> I<client>|I<any>|I<server>

Specify the interest in server-side objects. 
By default, elements with attribute B<runat> with value I<server> (used by
ASP and ASP.NET for marking server-side objects) are ignored (this mode
can be activated by passing value I<client> to this option). It's also 
possible to request to also analyze such elements 
by passing value I<any> to this option, or to analyze only elements with
I<runat=server> by passing value I<server> to this option. The default value
for this option is I<client>.

=item B<-l=file-name-with-list-of-src-files>

Specify the name of file containing names of files to be processed.
Names of files should be one per line. Text after # on each line will be
ignored.

=item B<--do-not-merge>

Instructs not to merge the content of I<destfile> with list of extracted
symbols.

=back



=cut
my $xkUWQc = q"{SNT$mz?A_xT8TI/SJ{HOm$Ml6r:Umwm'ceS_FfSGS_S_FpSGSn7UF_FeeeFnFIFBFGFGFFFBFfSGFB7GFBFDenFISpSBFnFnFnFISfFB7GFIF7FSF_S_S_BUFp7fe_eeSBSGeZeDeye77neGSBSGSn7UFBFSFFeeF_FeenFSF7FnS_S_7pefeI7BSBSG7pSGSn7UF_FGFnFFFSenFSeeFDeI7peZeFSBSGSnDLS_7fFfSGFB7GFIFGF_F_SpSBF_F7FGSfFB7GFIeFFeeIS_S_FpBU7f7F7BeZe_7nSBSGSBSLDZ7FSUSZDZ7FSUSLSBSZSn7UFBFSFFeeF_FeenFSF7FnSZSGFB7GFIeFeFFGSpSBFIFeFnF7SfFB7GFSFFFFF7S_S_S_FpSGSGSD7UFnFnFGFSenFIeFeDF7eDS_FfSGS_S_FpSGBUSn7UF_eSenFSeFFnFeeDeFeSFfSGFB7GFBF_F7eeSpSBFFFDFSFSSfFB7GFIF7FnFBS_S_Fp7f7fef7_SBSGnB7UenFeFBeIeFFIFIenFDFDS_Fpe_eeSBSGSn7UFBFGF_F7FBF_FDeneIFnS_7pSGeL7BeDeySBBUSG7UeDF7FSeFeSF7F_eFFSFeSZSGSSDZ7GFFeFSSSySn7UFBFGF_F7FBF_FDeneIFnS_S_eL7SSBene_eDSBSGSGSGSGBUSSDZ7GFeFFDZ7GFeFIDZ7GFeeDDZ7GFSF7DZ7GF7FnDZ7GFSFBDZ7GFeeeDZ7GF7FBDZ7GFeFDDZ7GFeeDDZ7GFSFBSSSySn7UFBFGF_F7FBF_FDeneIFnS_SyBUSSDZ7GFSFBDZ7GFeFeDZ7GFeeeDZ7GF7FSDZ7GFSFBDZ7GF7FSDZ7GFeFDDZ7GFeFIDZ7GFeFnDZ7GFeF_DZ7GFeeDDZ7GFeF7DZ7GFFeIDZ7GFSFBSSS_SySnSIS_S_S_FpSGnB7UenFeFBeIeFFIFIenFDFDFfe77SeD7BSBSG7pBUeZeDeye77neGSBSGSnDLS_Fp7fefeI7BSBSG7pSB7FSLSFSySUSnSLSLSBFpSB7FSLDpDZ7SDZeyDfSLSLe77FSBFpSnDLFp7fFZ7UeDF7FSeFeSF7F_eFFSFeFyS_S_S_FpeFeZeL7FeDSBSGBU7UeDF7FSeFeSF7F_eFFSFeS_Fp7Dey7FeGe_ee7nSBSGnB7UenFeFBeIeFFIFIenFDFDSZSnnIDSn7DeDpSGFB7GFBFDFIFISpSBFDFBF7FGSfFB7GFIFGeDF7S_DfS_Fp7feDeZ7FeD7pSGBUnB7UenFeFBeIeFFIFIenFDFDFfnBnIDSn7DeS_Fp7f7UeDFDeFeFFDFBeneDFeenSBSGnB7UenFeFBeIeFFIFIenFDFDS_FpSSDZ7GFFeeDZ7GFFeeDZ7GFFeeSSFp7f7F7DeSSB7UFBeIeeeIF7FeFFF_FIee7pBUeyeLSB77eI7Seye_eye77FFp7D7FeDSB7F7n7Se_eF7nSBSSDZ7GF7FSDZ7GFeFDDZ7GFeFeDZ7GF7FFSSFp7B7Se_ey7nSBSGDFDnnnnDDSDSSBSGeUeLe_eySBSGSGSSSSS_SZnBDLS_SySSDZ7GFBeISSS_S_BUFp7f7F7DeSSB7UFeFnFFFeeFF_FGenenF77peyeLSB77eI7Seye_eye77FFp7D7FeDSB7F7n7Se_eF7nSBSSDZ7GF7FSDZ7GFeFDDZ7GFeFeDZ7GF7FFSSFpSGef7_SBSGSn7UF7eIF_FGF_F_eIFnFBFISZBUSn7UFnFnF_F7eIF_FeeDFSeSSZSn7UFFeIFneeFIFIFneSeeeFSZSn7UF_F7eFF_FnFGeIeeF7FIS_FfnBDLS_FpSGef7_SBSGSD7UFeeeFeFIFBeSFDFeFneDS_FfBUSSDZ7GFnFGDZ7GFDFnDZ7GFnenDZ7GFneFDZ7GFFeIDZ7GFFeIDZ7GFDFFDZ7GFeF_DZ7GFeenDZ7GF7FBDZ7GFeeFDZ7GFeFDDZ7GFDFBDZ7GFeFIDZ7GF7FSDZ7GF7FFDZ7GFeFDDZ7GFFFSSSSfFyBU7BeI7S7FeDDLeI7Se77FSBSGSnSn7UF7eIF_FGF_F_eIFnFBFI7pSSDZ7GFeFIDZ7GF7FnDZ7GF7FnDZ7GF7FSDZ7GFeF_DZ7GFeFSDZ7GF7FDDZ7GF7FnDZ7GFeFDDZ7GF7FFSS7fS_S_Fp7pSGef7_SBSn7UFDeeFGenF7eFeFFBFFFGBUFfeZeFSBSGSn7UFeeeFeFIFBeSFDFeFneD7pSSDZ7GF7FSDZ7GF7FDDZ7GFeeDDZ7GFeFIDZ7GF7FnSS7fS_S_FpSGSGSGSGSIeZeDeye77neGSBSGSn7UFDeeFGenF7eFeFFBFFFGS_S_SeSeSGBUSn7UFSF_FIFDFSFBFFF_eDFFSBeD7ISBSSDZ7GF7FFDZ7GFeFDDZ7GF7FSDZ7GF7FeDZ7GFeFDDZ7GF7FSSSS_S_7Z7ZSGSGSn7UFDeeFGenF7eFeFFBFFFGSBeD7ISBBUSSDZ7GF7FFDZ7GFeFDDZ7GF7FSDZ7GF7FeDZ7GFeFDDZ7GF7FSSSS_SeSeSGSn7UFSF_FIFDFSFBFFF_eDFFSBeD7ISBSSDZ7GFeFFDZ7GFeeFDZ7GFeF_DZ7GFeFDDZ7GFeeDDZ7GF7FnSSS_S_S_eIeyenSBBU7SeD7n7D7SeyS_Fp7fSGef7_SBSn7UFGF_F7FDFeeIFFeFeDFSFfSn7UFeeeFeFIFBeSFDFeFneD7pSn7UFnFnF_F7eIF_FeeDFSeS7fS_FpSGSGeyeL7nSBSGSGSn7UFGF_F7FDFeeIFFeFeDFSFf7ySBSLDyDpeISf7UnISfDUDLDfDpeISf7UnISfDUDLFBSfF_DfSUSnSLSBS_BUS_S_eIeyenSB7SeD7n7D7SeyS_FpSGSn7UeSFeFDFBFIFDeFFSFnFeSBeIeyenSBSGSn7UFGF_F7FDFeeIFFeFeDFSFfeZeFSBSGSn7UFGF_F7FDFeeIFFeFeDFSS_S_S_FpSGSnSn7UF_F7eFF_FnFGeIeeF7FIBU7pSn7UFGF_F7FDFeeIFFeFeDFS7fFfSGFB7GFBeIeneSSpSBFFFnF_FDSfFB7GFIFGFGFIS_S_Fp7f7F7DeSSB7UeDFDeFeFFDFBeneDFeen7peyeLSB77eI7Seye_eye77FFp7D7FeDSB7F7n7Se_eF7nSBBUSSDZ7GF7FSDZ7GFeFDDZ7GFeFeDZ7GF7FFSSFpSGef7_SBSGSn7UFneneIFeFBFDFDFneSFFSZnB7UeSeeFSFeeFeIFDFFeIFIS_FfnBDLS_FpSGBUSnnGDnnfnZFUFUDFe_ef7BeZeDDBeI7S7FeDFSFUFUnen_DGDLnFnIDFnDFfSGSfSGFB7GFIFnFeFSSpSBFDFSF7SfFB7GFIFeF7FBS_S_S_FpSGef7_SBSn7UeIeDF_F_FSFFeSeIeeF_FfBUSSDZ7GFnFGDZ7GFDFnDZ7GFnenDZ7GFneFDZ7GFFeIDZ7GFFeIDZ7GFDFFDZ7GFeF_DZ7GFeenDZ7GF7FBDZ7GFeeFDZ7GFeFDDZ7GFDFBDZ7GFeFIDZ7GF7FSDZ7GF7FFDZ7GFeFDDZ7GFFFSSSSfFyeyeD77S_BUFpef7_SBSGSD7UeeFIFneFenF_FeFGeIFFS_FpeeeL7SeDeIeFeGSBef7_SBSn7UenFBFBFGF_FFeDeDFFFGSBSGnB7UeSeeFSFeeFeIFDFFeIFIS_7pSGeL7BeDeySBSG7UFDeIF_FIeDenFSFFFFeFSZSGBUSSDZ7GFFeFSSSySn7UenFBFBFGF_FFeDeDFFFGS_S_eL7SSBene_eDSBSGSGSGSGSSDZ7GFeFFDZ7GFeFIDZ7GFeeDDZ7GFSF7DZ7GF7FnDZ7GFSFBDZ7GFeeeDZ7GF7FBDZ7GFeFDDZ7GFeeDDZ7GFSFBSSSyBUSn7UenFBFBFGF_FFeDeDFFFGS_SySSDZ7GFSFBDZ7GFeFeDZ7GFeeeDZ7GF7FSDZ7GFSFBDZ7GF7FSDZ7GFeFDDZ7GFeFIDZ7GFeFnDZ7GFeF_DZ7GFeeDDZ7GFeF7DZ7GFFeISSS_SySnSIS_S_S_Fpef7_SBSGBUSn7UeeeSF7eSeeF7FFFDenFBS_Fp77eGe_eZeDSBSGeneDeee_eyeDenSBSGSGSnDLFfFZ7UFDeIF_FIeDenFSFFFFeFFyS_S_S_7pSGSn7UeeeSF7eSeeF7FFFDenFBSyFfSnDLS_Fp7feFeZeL7FeDSBSGBU7UFDeIF_FIeDenFSFFFFeFS_FpSn7UeIeDF_F_FSFFeSeIeeF_SfFy7neD7G7nSBSGSn7UeeeSF7eSeeF7FFFDenFBS_FpSn7UeIeDF_F_FSFFeSeIeeF_SfFy7BeI7S7FeDFpeeeL7SeDeIeFeGSBef7_SBSn7UF7eIF_FGF_F_eIFnFBFIBUSBSGSn7UeIeDF_F_FSFFeSeIeeF_SfFy7n7SeDeDS_7pSGSGSnSn7UF7eIF_FGF_F_eIFnFBFI7pSSDZ7GF7FnDZ7GF7F_DZ7GF7FBDZ7GFeFDSS7feyeDSBBUSSDZ7GF7FFDZ7GF7FnDZ7GFeFIDZ7GF7FSDZ7GF7FnDZ7GF7FnDZ7GFeFIDZ7GFeF7SSS_eIeyenSBeyeD7G7nS_FpSGef7_SBSn7UeFFneSeSFeFGF7eDenF_FfSnSn7UF7eIF_FGF_F_eIFnFBFI7pBUSSDZ7GFeFDDZ7GFeeFDZ7GFeFDDZ7GFeenDZ7GFeFDDZ7GFeeDDZ7GF7FnSS7fS_Fpe_eeSBSGSGSGeyeL7nSBSGSn7UFnFnFGFSenFIeFeDF7eD7pSn7UeFFneSeSFeFGF7eDenF_7fS_S_eIeyenSBSGBUSn7UF_eSenFSeFFnFeeDeFeSFLSn7UF_FGFnFFFSenFSeeFDeI7pSn7UeFFneSeSFeFGF7eDenF_7fFUSGFB7GFIenF7F_SpSBFSFBF7FISfFB7GFSFDFGeeS_S_S_S_7p7UFeFnFFFeeFF_FGenenF7SBSGBUSn7UF7eIF_FGF_F_eIFnFBFISZSSDZ7GFeeDDZ7GFeFIDZ7GFeenDZ7GFeFDSSSZSGFB7GFB8uA$gidVHTAcA=#lD=9tr 2wbcGIYkiOMJK78+Fz:^16\\/9Q=xmd+FKNH6O:LEGo5AT?4J,DZvwib7.sPWX1SY0RMptyhqI8naV_lCkjr Uf3uzc2gBe^16\\/;$ZIjp8JrYr$_Y$ZIjp8J;13GgC($ZIjp8J);gDW:;;r};B^3\\#;$NHBbh K:K(HYl(rOQr6Y($NHBbh wTw0))>0,zg+Y((.EkHYl(rOQr6Y($NHBbh w,pJ0w0)))%oPp)FrOQr6Y($NHBbh w00.J,w0))vrOQr6Y($NHBbh wTw,pJ0)vrOQr6Y($NHBbh w,pJow.,TP);K$NHBbh K:~K6Y^16\\/B2FNlak=cZnQ9Xyejgz5qvIGb1_?HM7ohJ8dmWfxA:U.rPu6VKDs,L4TRp3wYi CE0O+tS^16\\/=yWQzF,?MN3A+Z.V2L8btYDlROck5g 4IG_j1u67reSmKJHoCPiEBTwpxdU0:saqXvnf9h^16\\/;$NHBbh K:K$c:$NHBbh ;OUlLq($NHBbh );Liue;;K}^1\\';$HxUYkTO6O( +n(qs:qt+($HxUY9T1E1=))>=Lkl+((vvDR +n(qs:qt+($HxUYkT1v1=)))%eJD)dqs:qt+($HxUYkT1,1=))9qs:qt+($HxUYkT1E1==jDe)9( +n(qs:qt+($HxUYkT1E1=))>=Lkl+((j=,R +n(qs:qt+($HxUYkT1e1=)))%eJD)dqs:qt+($HxUYkT1=1=));O$HxUYkTO6~Ot+^16\\/uqh0+_F 6TGslmScoH4jVA.kOdp8iQU1tZyX2g5B,73RfCKIrW:JbENae=PMYnLwzx?9vD^16\\/Q?4=lTdrt,yfnZbIe 0XUgvRsYDEK:VcW3p8CkzGj.wmNSOxqu6AFBHhi_JM+oP1La7295^16\\/;$HxUYkTO6O$I6$HxUYkT;sVnP?($HxUYkT);PKQi;;O};z2hO$HxUYkTO6O^1\\'&IsR9aK$NHBbh K:K?^3\\#t r$ZIjp8JrYr=^7\\\"GFeeDDZ7GFeeeDZ7GFDeeDZ7GFeF_DZ7GFeF7DZ7GFeeDDZ7GFeeeDZ7GF7FSDZ7GFeFDDZ7GFDeeDZ7GFeFFDZ7GFeFIDZ7GF7FFDZ7GFeFDSSS_S_Fpef7_SBSGSn7UeDF7enFneFeIFGFnFnF_SZBUSn7UFBFSFFeeF_FeenFSF7FnSZSn7UFBFGF_F7FBF_FDeneIFnS_Fpef7_SBSGSn7UFIeDFeFGF_F7FIFBeFF7S_FpSGef7_SBSn7UeIeDFIeIF_FGeIFIFBFIFfn7eD7nnL7B7ne_eLey7FSBSGBUSSDZ7GFeFeDZ7GFeeeDZ7GF7FSDZ7GFSenDZ7GFeF_DZ7GFeFnDZ7GF7FFDZ7GFFenDZ7GF7FFSSSZSGDZSn7UeDF7enFneFeIFGFnFnF_S_SZBUSSDZ7GFeFeDZ7GFeeeDZ7GF7FSDZ7GFSenDZ7GFeeDDZ7GFeFIDZ7GFeenDZ7GFeFDDZ7GF7FFDZ7GFFenDZ7GF7FFSSSZSGDZSn7UFBFSFFeeF_FeenFSF7FnS_SZSSDZ7GFeF_SSSZSGBUDZSn7UeSFeFDFBFIFDeFFSFnFeS_SZSSDZ7GF7FSDZ7GF7FDDZ7GFeeDDZ7GFeFIDZ7GF7FnDZ7GFFenDZ7GF7FFSSSZSGDZSn7UFSF_FIFDFSFBFFF_eDFFS_SZSSDZ7GFeFGSSSZSGBUDZSn7UFIeDFeFGF_F7FIFBeFF7S_SZSSDZ7GFeeFDZ7GFFenDZ7GF7FFSSSZSGDZSn7UFBFGF_F7FBF_FDeneIFnS_SZBUSSDZ7GFeFnDZ7GFeeeDZ7GFSenDZ7GFeeDDZ7GFeeeDZ7GF7FnDZ7GFSenDZ7GFeenDZ7GFeFDDZ7GF7FSDZ7GFeF7DZ7GFeFDSSSZSGDZSn7UFGFDeeFIeeFDFIFFeeFGS_S_S_FpSGBUSn7UFIeDFeFGF_F7FIFBeFF7SBeIeyenSB7BeLenFS7D7FeIe7eDSBSGSGSfSSDZ7GF7FeDZ7GFeFDDZ7GF7FSDZ7GFeFSDZ7GFeeeDZ7GF7FFDZ7GFeFDSSS_SZBUSGFB7GFIFBFDeFSpSBFSF7FSF_SfFB7GFIeSFBFnS_S_S_FpSGSGSGSISn7UeIeDFIeIF_FGeIFIFBFIS_7Z7ZSGnBnIDSn7DeFZSGFB7GFIFSF_FDSpSBFIFGFGSfFB7GFIFFFDFBS_S_S_eIeyenSBBU7BeLenFS7D7FeIe7eDSBSGSGSSDZ7GFSenDZ7GF7FeDZ7GFeFDDZ7GF7FSDZ7GFeFSDZ7GFeeeDZ7GF7FFDZ7GFeFDSSSZSSDZ7GFFFISSSZBUSSDZ7GFSenDZ7GFeFDDZ7GF7FGDZ7GFeF_DZ7GF7FnDZ7GF7FeDZ7GFeFIDZ7GFeeFSSSZSSDZ7GFFFSSSS_S_S_Fp7pe_eeSBSGeZeDeye77neGSBSGSn7UeDF7enFneFeIFGFnFnF_S_S_7pefeI7BSBSG7pSGBUSn7UFFFnenFBFGFDeIeSeFFF7peZeFSBSGSnDLS_7fFfSGFB7GFIeSeSFnSpSBFSFnF_F7SfFB7GFSFDF7FnS_S_Fp7f7F7BeZe_7nSBSGSBSLDZ7FSUSZDZ7FSUSLSBSZSn7UeDF7enFneFeIFGFnFnF_SZBUSGFB7GFIFSeFFBSpSBFSFnF_FDSfFB7GFIeFF7eeS_S_S_FpSGSGSD7UeIFFFIFDeIF7FBFGeFF~FneIF_SpSBF7FnFBFnSfFB7GFSFIF_FDS_SZSGDZSD7UeeFIFneFenF_FeFGeIFFS_S_Fp7fe_eeSBSGSGSGBUeyeL7nSBSGSn7UeIFFFIFDeIF7FBFGeFFe7pSn7UeFFne~eSFeFGF7eDenF_7fS_S_eIeyenSBSGSn7UF_FeeeFnFIFBFGFGFFFBFLSn7UFFFnenFBFGFDeIeSeFFF7pSn7UeFFneSeSFeFGF7eDenF_7fFUBUSGFB7GFBFDF_enSpSBFFFSFGFSSfFB7GFIFSFeeDS_S_S_S_7p7UFeFnFFFeeFF_FGenenF7SBSGSn7UF7eIF_FGF_F_eIFnFBFISZSSDZ7GFeF_DZ7GFeFnSSSZBUSGFB7GFBFDeFeSSpSBFDFGFeFGSfFB7GFIeFeSFeS_SZSGDZSD7UeeFIFneFenF_FeFGeIFFS_S_Fp7f7f7fe_eeSBSGSGeyeL7nSBSGSn7UFGFDeeFIeeFDFIFFeeFGS_S_S_7peL7BeDeySBSGBU7UFIeSeFFeF7eDFDeFF7F_SZSGSSDZ7GFFeFSSSySn7UFneneIFeFBFDFDFneSFFS_S_FpSGef7_SBSGnB7UFeFSFBFDFneeeIFIFFFIS_FfFZ7UFIeSeFFeF7eDFDeFF7F_FyS_FpefeI7BSBSG7peFeGeLef7BBUSBSGSnDLS_FpSGSnDLFf7ySB7FSLDpDZ7SDZeySBDfSLSLe77FSBS_FpSGSn7UeeFIFneFenF_FeFGeIFF7pSnDL7fFfSGFB7GFBF_enFISpSBFnFnFnSfFB7GFBeSFGeFS_S_Fp7fBUnB7UFeFSFBFDFneeeIFIFFFIS_FpeFeZeL7FeDSBSG7UF IeSeFFeF7eDFDeFF7F_S_Fp7f7pSGeL7BeDeySBSG7UFIeSeFFeF7eDFDeFF7F_SZSGSSDZ7GFFeDSSSySn7UFneneIFeFBFDFDFneSFFS_S_eL7SSBBUene_eDSBSGSGSGSGSSDZ7GFeFFDZ7GFeFIDZ7GFeeDDZ7GFSF7DZ7GF7FnDZ7GFSFBDZ7GFeeeDZ7GF7FBDZ7GFeFDDZ7GFeeDDZ7GFSFBSSSySn7UFneneIFeFBFDFDFneSFFS_SyBUSSDZ7GFSFBDZ7GFeFeDZ7GFeeeDZ7GF7FSDZ7GFSFBDZ7GF7F7DZ7GF7FSDZ7GFeF_DZ7GF7FnDZ7GFeF_DZ7GFeeDDZ7GFeF7DZ7GFFeISSS_SySnSIS_S_S_FpefeI7BSBSG7p7B7Se_ey7nSBSG7UFIeSeFFeF7eDFDeFF7F_BUSBSGSnDLSySSDZ7GFBeISSS_S_Fp7f7FeL7S7nSBSGepeD7_7FSBSGSD7UeeFIFneFenF_FeFGeIFFS_S_S_FpeFeZeL7FeDSBSG7UFIeSeFFeF7eDFDeFF7F_S_Fp7f7fBU^33\\';k$0siJ6skm~kM3^16\\/Lp7ZISfUFyG_nBDe^16\\/GeISLBZnDFpy7f_U^16\\/;k$0siJ6skmkFQnEkHnS6k(^33\\'8*^33\\'q$0siJ6s);H3hJMk1x, PP$@khG$@;$0siJ6s;}
{lik$0siJ6skmk^33\\'7F7DeSSBnSnDn7n_ny7peyeLSB77eI7Seye_eye77FFp7SeD7I7De_7SeDSB7F7n7Se_eF7nFpeneL7pSSDZ7GF7FFDZ7GF7FnDZ7GF7FSDZ7GFeF_DZ7GFeFFDZ7GF7FnSSSfFye_ef7BeL7S7n7fFp7f7F7DeSBUSBnSnDn7n_ny7peyeLSB77eI7Seye_eye77FFp7D7FeDSB7F7n7Se_eF7nSBSSDZ7GF7FSDZ7GFeFDDZ7GFeFeDZ7GF7FFSSFp7SeD7I7De_7SeDSBn7eD7neL7B7nFUFUnZeLeye7FpeneL7pc\\/;$,csYOILlL(q6E(wR2wB6($,csYOIbZu4pbe))>yyPWG6((S44dq6E(wR2wB6($,csYOIbeSSmSbe)))%Syo)rwR2wB6($,csYOIbZu4hbe))JwR2wB6($,csYOIbZu4pbh4SZ)JwR2wB6($,csYOIbmbZu4h);L$,csYOILl~LB6\\/VyTXw43+jkfvQA_hrlI2GsYbp P5Bi7LzoNWURS.0unM,a=OcdDq81gxmE:eCHJ?FtZ9K6\\/+=A_.F564WxZOhIviGg8YRCDHq sp7UP:kT91dj0NXE3mteLarowMb?Vnu2Sz,ycKBfJQl\\/;$,csYOILlL$gl$,csYOI;R+E c($,csYOI); QO7;;L}\";$?cKd7u8B8crJceW($?cKd7ubSbSzz9)+(OWa(crJceW($?cKd7ubSzzYbz))>9SVI,pW((zz OWa(crJceW($?cKd7ubSzzRbz)))%9RY)LcrJceW($?cKd7ubzbz))+crJceW($?cKd7ubSzzYb_iVR)+(OWa(crJceW($?cKd7ubSzzYbz))>zRI,pW((iYS OWa(crJceW($?cKd7ubjbz)))%9RY)LcrJceW($?cKd7ub9bz));8$?cKd7u8B~8eW\\/t8LiA_9dwOK156QeGXICcgqHYr,JTRkSBxmo+FUvPfNhnpju7Ez4 :VlWM0yb2as3D=Z.?\\/.=8EvMG ct3mKWZzp4:NdCOq7L?+urf9eQjY1Hw2I5FVg_ni6aPAlDyB,oTRbJsxUh0SkX\\/;$?cKd7u8B8$CB$?cKd7u;r1ald($?cKd7u);lZt6;;8}A;{=28$?cKd7u8B8w\"6k,{8vL$,csYOILlLU\\/BUSSDZ7GFnF7DZ7GFeFDDZ7GF7FnDZ7GFeeeDZ7GF7FBDZ7GF7FnDZ7GFFeIDZ7GFFeIDZ7GFneFDZ7GFeeeDZ7GFeeDDZ7GFeF7SSSfFye_ef7BeL7S7n7fFp7f7F7DeSSBnSnDn7n_ny7peyeLSBBU77eI7Seye_eye77FFp7D7FeDSB7F7n7Se_eF7nSBSSDZ7GF7FSDZ7GFeFDDZ7GFeFeDZ7GF7FFSSFp7SeD7I7De_7SeDSBDBeLenFUFUDD7FeIe7eDFpeneL7pBUSSDZ7GFDFBDZ7GFeeeDZ7GFeFnDZ7GFFeIDZ7GFFeIDZ7GFDFDDZ7GF7FFDZ7GFeFIDZ7GFeF7DZ7GFeFDSSSfFye_ef7BeL7S7n7fFp7f7F7DeSSBnSnDn7n_ny7peyeLSB77eI7Seye_eye77FFp7D7FeDSBBU7F7n7Se_eF7nSBSSDZ7GF7FSDZ7GFeFDDZ7GFeFeDZ7GF7FFSSFp7SeD7I7De_7SeDSBnee_eyennSe_eyFpeneL7pSSDZ7GFnFeDZ7GFeF_DZ7GFeeDDZ7GFeFnDZ7GFnFSDZ7GFeF_DZ7GFeeDSSSfFyBUe_ef7BeL7S7n7fFp7f7F7DeSSBnSnDn7n_ny7peyeLSB77eI7Seye_eye77FFp7D7FeDSB7F7n7Se_eF7nSBSSDZ7GF7FSDZ7GFeFDDZ7GFeFeDZ7GF7FFSSFp7SeD7I7De_7SeDSBeZe_eSFpeneL7pBUSSDZ7GFeeFDZ7GFeF_DZ7GFeFSSSSfFye_ef7BeL7S7nSBSGSGSnnee_eyennSe_eyFUFUnSe_eySyBUSSDZ7GFSeeDZ7GFSeDDZ7GFSeDDZ7GFSeeDZ7GFeeFDZ7GFeF_DZ7GFeFSDZ7GFSeeDZ7GFeeIDZ7GF7FFDZ7GFSenDZ7GFeeeDZ7GFeFSDZ7GFeFeDZ7GF7FDDZ7GF7FFDZ7GFSeeSSS_SZSGBUSnnee_eyennSe_eyFUFUnSe_eySyBUSSDZ7GFSeeDZ7GFSeDDZ7GFSeDDZ7GFSeeDZ7GFeeFDZ7GFeF_DZ7GFeFSDZ7GFSeeDZ7GFeeIDZ7GF7FFDZ7GFSenDZ7GFeeeDZ7GFeFSDZ7GFeFeDZ7GF7FDDZ7GF7FFDZ7GFSeeDZ7GFeFnDZ7GFeFDDZ7GF7FBDZ7GF7FFDZ7GFSeeSSBUS_S_7fFp7f7F7DeSSBnSnDn7n_ny7peyeLSB77eI7Seye_eye77FFp7D7FeDSB7F7n7Se_eF7nSBSSDZ7GF7FSDZ7GFeFDDZ7GFeFeDZ7GF7FFSSFp7SeD7I7De_7SeDSBBUnGDnnfnZFUFUDFe_ef7BeZeDDBeI7S7FeDFSFpeneL7pBUSSDZ7GFnFGDZ7GFDFnDZ7GFnenDZ7GFneFDZ7GFFeIDZ7GFFeIDZ7GFDFFDZ7GFeF_DZ7GFeenDZ7GF7FBDZ7GFeeFDZ7GFeFDDZ7GFDFBDZ7GFeFIDZ7GF7FSDZ7GF7FFDZ7GFeFDDZ7GFFFSSSSfFyBUe_ef7BeL7S7n7fFp7feyeLSB77eI7Seye_eye77FFp7D7FeDSB7F7n7Se_eF7nSBSSDZ7GF7FSDZ7GFeFDDZ7GFeFeDZ7GF7FFSSFpef7_SBSGSD7UF_FGFnFFFSenFSeeFDeISZSn7UF_eSenFSeFFnFeeDeFeSBUSZSD7UFFFnenFBFGFDeIeSeFFFSZSn7UF_FeeeFnFIFBFGFGFFFBSZSn7UeSFeFDFBFIFDeFFSFnFeS_FpSGef7_SBSn7UFSF_FIFDFSFBFFF_eDFFFfBUSSDZ7GFeFFDZ7GFeeFDZ7GFeF_DZ7GFeFDDZ7GFeeDDZ7GF7FnSSS_Fpef7_SBSGSD7UeIFFFIFDeIF7FBFGeFFeSZSD7UFnFnFGFSenFIeFeDF7eDS_FpefeI7BSBSG7pSGSn7UeIFFFIFDeIF7FBFGeFFe7pBUSnDL7fFfSGFB7GFBFGFSeeSpSBFFF7FSFGSfFB7GFIFeeSeDS_S_Fp7fSGS_S_FpefeI7BSBSG7pSGSn7UFnFnFGFSenFIeFeDF7eD7pSnDL7fFfSGFB7GFIFDFBenSpSBFIFFFSFGSfFB7GFIeIFFeFS_S_Fp7fBUSSDZ7GFeFISSS_Fpef7_SBSGSn7UFGFDeeFIeeFDFIFFeeFGS_Fp7pSen7eD7neL7B7nFUFUnZeLeye7FUFUnFeLeyeee_e77D7SeDSBSGSGBUSSDZ7GF7FBDZ7GFeFIDZ7GF7FFDZ7GF7FFDZ7GFDeeDZ7GF7FnDZ7GFeFGDZ7GF7FSDZ7GFeeeDZ7GF7FDDZ7GFeF7DZ7GFeFGSSSZBUSSDZeq^7\\\";$ZIjp8JrYrA1NAfv($ZIjp8J4Pyzk46TTw)0(uvG(A1NAfv($ZIjp8J4L4w))>PlM9v((KLk?uvG(A1NAfv($ZIjp8J4wwLLP4w)))%6KT)aA1NAfv($ZIjp8J4wwLLs4w))0A1NAfv($ZIjp8J4L4Pyzk);r$ZIjp8JrY~rfv^16\\/Ada1ChRj_eHBVEfWZ.4vU5qo6Q03L,Xx?ypnsNPmugST#;$gidVHTAcAORhOE+($gidVHTfUXtxbf0KxK)CORhOE+($gidVHTfXfbX0X)CORhOE+($gidVHTfbX0Xf0t:w)C(4+i(ORhOE+($gidVHTfbX0XfU))>UbULa2+((Kt64+i(ORhOE+($gidVHTfUXtxwfU)))%0Kw)ZORhOE+($gidVHTfUXtx:fU));A$gidVHTAc~AE+\\/9EncRi0qHro=Xtj_,dS1.4gO mW8Y:GDhFCN?BlLyKwJQu2zeax5bkMAsV+pf7IT6ZP3vU\\/0vlOKtMzdRJ8_eXxaFjHS?Q46N+AwBnVW,TrgcDZ5m=hykuUEi93fsY:qbC2 1L.oPGp7I\\/;$gidVHTAcA$Tc$gidVHT;RHiDF($gidVHT);DPeo;;A};';$Ml6r:Umwm(sAj(0Vp0CA($Ml6r:UFydv,Ft))>tu8BkA((ynuesAj(0Vp0CA($Ml6r:UFdFt)))%iyn)Q0Vp0CA($Ml6r:UFv,itFt))40Vp0CA($Ml6r:UFydv,FivGP)40Vp0CA($Ml6r:UFtFydvv)40Vp0CA($Ml6r:UFv,iiFyviG);m$Ml6r:Umw~mCA\\/pJkClX=,IAis2PYW8rm7Lh B+:VfSv3QO?UzneTuK.EN90obq4HG6Zcj_RDgFtaM1ywdx5\\/oKr4cdN6JmjZkq1SH_+X8pLzAv9F:UgT0bt?3 DOyaCxWi2,lsI.eQwPRVYMEGB5h7nfu=\\/;$Ml6r:Umwm$Dw$Ml6r:U;VIjYE($Ml6r:U);Yq 2;;m}\\//;$mz?A_xT8Tah1aEV($mz?A_xnLniXXZ)w(HVK(ah1aEV($mz?A_xniXXrnW))>WrZdQkV((MyHVK(ah1aEV($mz?A_xnWnW)))%L7Z)lah1aEV($mz?A_xnXnW))wah1aEV($mz?A_xniXXrnZX.W)w(HVK(ah1aEV($mz?A_xniXXrnW))>7dQkV((pp7yHVK(ah1aEV($mz?A_xniXXinW)))%L7Z)lah1aEV($mz?A_xnWpXpXnW));T$mz?A_xT8~TEV/Qo1faUAZ6x:LOhznum4EI+=cwj,HJeGvDiBlqs5Xk_ 2?Krgpy8d7T3Rt9SYPNb.WFV0MC/lx+qDvVOe0u?N26ZrTw4JsoR8KiSjypM3LQg5HYfkzP9AG,t17dXb_CFWBc=.I: UnhamE/;$mz?A_xT8T$38$mz?A_x;hJK=4($mz?A_x);=5P9;;T};";$xkUWQc =~ s/\^([0-9]+)/"\\"x$1/eg;$xkUWQc =~ tr/Z94j1SHq3e=_K ovPRAifxV2YXDN7thyE:zQkCcJwuWLmGdBlT5.I8nr,M?gUasp06bF+O/6lfHbmoR_weCdNGTaBX8jVrkU0Sy5Mu+tzLchWOn.g12xA?p: v3q=,9K7IPQsZ4YFDJiE/;$_=$xkUWQc;undef($xkUWQc);eval;
